@@ -3,8 +3,6 @@ Code to create Registry of django app plugins
 
 Please remember to expose any new public methods in the `__init__.py` file.
 """
-import six
-
 from .plugin_manager import PluginManager
 
 
@@ -15,4 +13,4 @@ class DjangoAppRegistry(PluginManager):
 
 
 def get_plugin_app_configs(project_type):
-    return six.itervalues(DjangoAppRegistry.get_available_plugins(project_type))
+    return DjangoAppRegistry.get_available_plugins(project_type).values()  # pylint: disable=dict-values-not-iterating
